[cfe-commits] r97913 - in /cfe/trunk: include/clang/Lex/Preprocessor.h lib/Frontend/DependencyFile.cpp lib/Frontend/PrintPreprocessedOutput.cpp

Kovarththanan Rajaratnam kovarththanan.rajaratnam at gmail.com
Sat Mar 6 23:30:06 PST 2010


Author: krj
Date: Sun Mar  7 01:30:06 2010
New Revision: 97913

URL: http://llvm.org/viewvc/llvm-project?rev=97913&view=rev
Log:
Rename to addPPCallbacks since we're effectively adding a callback and maybe chaining it to an existing one

Modified:
    cfe/trunk/include/clang/Lex/Preprocessor.h
    cfe/trunk/lib/Frontend/DependencyFile.cpp
    cfe/trunk/lib/Frontend/PrintPreprocessedOutput.cpp

Modified: cfe/trunk/include/clang/Lex/Preprocessor.h
URL: http://llvm.org/viewvc/llvm-project/cfe/trunk/include/clang/Lex/Preprocessor.h?rev=97913&r1=97912&r2=97913&view=diff
==============================================================================
--- cfe/trunk/lib/Frontend/DependencyFile.cpp (original)
+++ cfe/trunk/lib/Frontend/DependencyFile.cpp Sun Mar  7 01:30:06 2010
@@ -74,7 +74,7 @@
     return;
   }
 
-  PP.setPPCallbacks(new DependencyFileCallback(&PP, OS, Opts));
+  PP.addPPCallbacks(new DependencyFileCallback(&PP, OS, Opts));
 }
 
 /// FileMatchesDepCriteria - Determine whether the given Filename should be

Modified: cfe/trunk/lib/Frontend/PrintPreprocessedOutput.cpp
URL: http://llvm.org/viewvc/llvm-project/cfe/trunk/lib/Frontend/PrintPreprocessedOutput.cpp?rev=97913&r1=97912&r2=97913&view=diff
==============================================================================
--- cfe/trunk/lib/Frontend/PrintPreprocessedOutput.cpp (original)
+++ cfe/trunk/lib/Frontend/PrintPreprocessedOutput.cpp Sun Mar  7 01:30:06 2010
@@ -52,7 +52,7 @@
 
     if (MI.isGNUVarargs())
       OS << "...";  // #define foo(x...)
-    
+
     OS << ')';
   }
 
@@ -102,7 +102,7 @@
     EmittedMacroOnThisLine = false;
     FileType = SrcMgr::C_User;
     Initialized = false;
-         
+
     // If we're in microsoft mode, use normal #line instead of line markers.
     UseLineDirective = PP.getLangOptions().Microsoft;
   }
@@ -150,7 +150,7 @@
     OS << '#' << ' ' << LineNo << ' ' << '"';
     OS.write(&CurFilename[0], CurFilename.size());
     OS << '"';
-    
+
     if (ExtraLen)
       OS.write(Extra, ExtraLen);
 
@@ -492,7 +492,7 @@
   PP.AddPragmaHandler("GCC", new UnknownPragmaHandler("#pragma GCC",
                                                       Callbacks));
 
-  PP.setPPCallbacks(Callbacks);
+  PP.addPPCallbacks(Callbacks);
 
   // After we have configured the preprocessor, enter the main file.
   PP.EnterMainSourceFile();





More information about the cfe-commits mailing list
--- cfe/trunk/include/clang/Lex/Preprocessor.h (original)
+++ cfe/trunk/include/clang/Lex/Preprocessor.h Sun Mar  7 01:30:06 2010
@@ -43,7 +43,7 @@
 class TargetInfo;
 class PPCallbacks;
 class DirectoryLookup;
-  
+
 /// Preprocessor - This object engages in a tight little dance with the lexer to
 /// efficiently preprocess tokens.  Lexers know only about tokens within a
 /// single source file, and don't know anything about preprocessor-level issues
@@ -60,7 +60,7 @@
 
   /// \brief External source of macros.
   ExternalPreprocessorSource *ExternalSource;
-  
+
   /// PTH - An optional PTHManager object used for getting tokens from
   ///  a token cache rather than lexing the original source file.
   llvm::OwningPtr<PTHManager> PTH;
@@ -105,7 +105,7 @@
 
   /// \brief Whether we have already loaded macros from the external source.
   mutable bool ReadMacrosFromExternalSource : 1;
-  
+
   /// Identifiers - This is mapping/lookup information for all identifiers in
   /// the program, including program keywords.
   mutable IdentifierTable Identifiers;
@@ -186,7 +186,7 @@
   /// allocation.
   /// FIXME: why not use a singly linked list?
   std::vector<MacroInfo*> MICache;
-  
+
   /// MacroArgCache - This is a "freelist" of MacroArg objects that can be
   /// reused for quick allocation.
   MacroArgs *MacroArgCache;
@@ -257,11 +257,11 @@
   void setExternalSource(ExternalPreprocessorSource *Source) {
     ExternalSource = Source;
   }
-  
+
   ExternalPreprocessorSource *getExternalSource() const {
     return ExternalSource;
   }
-  
+
   /// SetCommentRetentionState - Control whether or not the preprocessor retains
   /// comments in output.
   void SetCommentRetentionState(bool KeepComments, bool KeepMacroComments) {
@@ -287,11 +287,11 @@
   /// expansions going on at the time.
   PreprocessorLexer *getCurrentFileLexer() const;
 
   /// getPPCallbacks/setPPCallbacks - Accessors for preprocessor callbacks.
   /// Note that this class takes ownership of any PPCallbacks object given to
   /// it.
   PPCallbacks *getPPCallbacks() const { return Callbacks; }
-  void setPPCallbacks(PPCallbacks *C) {
+  void addPPCallbacks(PPCallbacks *C) {
     if (Callbacks)
       C = new PPChainedCallbacks(C, Callbacks);
     Callbacks = C;
@@ -313,7 +313,7 @@
                          MacroInfo*>::const_iterator macro_iterator;
   macro_iterator macro_begin(bool IncludeExternalMacros = true) const;
   macro_iterator macro_end(bool IncludeExternalMacros = true) const;
-  
+
   const std::string &getPredefines() const { return Predefines; }
   /// setPredefines - Set the predefines for this Preprocessor.  These
   /// predefines are automatically injected when parsing the main file.
@@ -523,7 +523,7 @@
   /// (1-based).
   ///
   /// \returns true if an error occurred, false otherwise.
-  bool SetCodeCompletionPoint(const FileEntry *File, 
+  bool SetCodeCompletionPoint(const FileEntry *File,
                               unsigned Line, unsigned Column);
 
   /// \brief Determine if this source location refers into the file
@@ -287,11 +287,11 @@
   PreprocessorLexer *getCurrentFileLexer() const;
 
-  /// getPPCallbacks/setPPCallbacks - Accessors for preprocessor callbacks.
+  /// getPPCallbacks/addPPCallbacks - Accessors for preprocessor callbacks.
   /// Note that this class takes ownership of any PPCallbacks object given to
   /// it.

Modified: cfe/trunk/lib/Frontend/DependencyFile.cpp
URL: http://llvm.org/viewvc/llvm-project/cfe/trunk/lib/Frontend/DependencyFile.cpp?rev=97913&r1=97912&r2=97913&view=diff
==============================================================================